#+TITLE: A function to perform Org related searches in several places
#+AUTHOR: Juan Manuel Macías


#+begin_src emacs-lisp
  (require 'org-ql)

  (require 'hydra)
#+end_src

Path to Manual and local repo.

#+begin_src emacs-lisp
  (defvar org-manual-path "/path/to/org-manual.org")

  (defvar org-local-git-path "/path/to/org-mode/")
#+end_src

Previous functions.

#+begin_src emacs-lisp
  (defun my-org/search-prompt (query)
    (interactive
     (list
      (let* ((default (if (use-region-p)
			  (buffer-substring-no-properties
			   (region-beginning) (region-end))
			(thing-at-point 'symbol)))
	     (prompt (if default
			 (format "Search For (default %s): " default)
		       "Search For: ")))
	(read-string prompt nil nil default))))
    (format "%s" query))

  (defun my-org/search-manual (q)
    (org-ql-search
      org-manual-path
      `(regexp ,q)))

  (defun my-org/search-ml (q)
    (eww (format "https://orgmode.org/list/?q=%s" q)))

  (defun my-org/search-git-log (q)
    (with-current-buffer
	(find-file-noselect org-local-git-path)
      (vc-log-search q)))

  (defun my-org/search-reddit (q)
    (eww (format "https://www.reddit.com/r/orgmode/search/?q=%s" q)))
#+end_src

The function (first version).

#+begin_src emacs-lisp
  (setq my-org/search-info-actions-list
	'((?1 "Search Org mailing List"
	      (lambda (_)
		(interactive)
		(my-org/search-ml _)))
	  (?2 "Search Org Manual"
	      (lambda (_)
		(interactive)
		(my-org/search-manual _)))
	  (?3 "Search Org Git Log"
	      (lambda (_)
		(interactive)
		(my-org/search-git-log _)))
	  (?4 "Search Org Reddit"
	      (lambda (_)
		(interactive)
		(my-org/search-reddit _)))))

  (defun my-org/search-misc (query)
    (interactive
     (list (call-interactively #'my-org/search-prompt)))
    (let ((option (read-char-choice
		   (concat (format "Actions for \"%s\": \n\n" query)
			   (mapconcat (lambda (item)
					(format "%c: %s"
						(car item)
						(nth 1 item)))
				      my-org/search-info-actions-list "\n"))
		   (mapcar #'car my-org/search-info-actions-list))))
      (apply (nth 2 (assoc option my-org/search-info-actions-list))
	     (list query))))

#+end_src

Hydra version.

#+begin_src emacs-lisp
  (defun my-org/search-misc (q)
    (interactive
     (list (call-interactively #'my-org/search-prompt)))
    (defhydra hydra-search-org  (:color DarkRed
				 :hint nil)
      "
    _1_: Search Org mailing List
    _2_: Search Org Manual
    _3_: Search Org Git Log
    _4_: Search Org Reddit
    _q_: Quit
	"
      ("1" (lambda ()
	     (interactive)
	     (my-org/search-ml q)))
      ("2" (lambda ()
	     (interactive)
	     (my-org/search-manual q)))
      ("3" (lambda ()
	     (interactive)
	     (my-org/search-git-log q)))
      ("4" (lambda ()
	     (interactive)
	     (my-org/search-reddit q)))
      ("q" nil))
    (message (format "Actions for \"%s\"" q nil))
    (hydra-search-org/body))
#+end_src
